@@ -12,14 +12,14 @@
  * I. Lee Hetherington (ilh@lcs.mit.edu)
  *
  * 1.5 and later versions contain changes by, and are maintained by,
- * Eddie Kohler <kohler@icir.org>.
+ * Eddie Kohler <ekohler@gmail.com>.
  *
  * New change log in `NEWS'. Old change log:
  *
  * Revision 1.2  92/06/23  10:58:08  ilh
  * MSDOS porting by Kai-Uwe Herbing (herbing@netmbx.netmbx.de)
  * incoporated.
- * 
+ *
  * Revision 1.1  92/05/22  11:58:17  ilh
  * initial version
  *
@@ -101,10 +101,10 @@ pfb_output_end()
 #define HELP_OPT	303
 
 static Clp_Option options[] = {
-  { "block-length", 'l', BLOCK_LEN_OPT, Clp_ArgInt, 0 },
+  { "block-length", 'l', BLOCK_LEN_OPT, Clp_ValInt, 0 },
   { "help", 0, HELP_OPT, 0, 0 },
-  { "length", 0, BLOCK_LEN_OPT, Clp_ArgInt, 0 },
-  { "output", 'o', OUTPUT_OPT, Clp_ArgString, 0 },
+  { "length", 0, BLOCK_LEN_OPT, Clp_ValInt, 0 },
+  { "output", 'o', OUTPUT_OPT, Clp_ValString, 0 },
   { "version", 0, VERSION_OPT, 0, 0 },
 };
 static const char *program_name;
@@ -157,7 +157,7 @@ Options:\n\
   -h, --help                    Print this message and exit.\n\
       --version                 Print version number and warranty and exit.\n\
 \n\
-Report bugs to <kohler@icir.org>.\n", program_name);
+Report bugs to <ekohler@gmail.com>.\n", program_name);
 }
 
 #ifdef __cplusplus
@@ -173,16 +173,16 @@ main(int argc, char *argv[])
   const char *ifp_filename = "<stdin>";
   struct font_reader fr;
   int max_blocklen = -1;
-  
+
   Clp_Parser *clp =
     Clp_NewParser(argc, (const char * const *)argv, sizeof(options) / sizeof(options[0]), options);
   program_name = Clp_ProgramName(clp);
-  
+
   /* interpret command line arguments using CLP */
   while (1) {
     int opt = Clp_Next(clp);
     switch (opt) {
-      
+
      case BLOCK_LEN_OPT:
       max_blocklen = clp->val.i;
       if (max_blocklen <= 0) {
@@ -190,24 +190,24 @@ main(int argc, char *argv[])
 	error("warning: block length raised to %d", max_blocklen);
       }
       break;
-      
+
      output_file:
      case OUTPUT_OPT:
       if (ofp)
 	fatal_error("output file already specified");
-      if (strcmp(clp->arg, "-") == 0)
+      if (strcmp(clp->vstr, "-") == 0)
 	ofp = stdout;
       else {
-	ofp = fopen(clp->arg, "wb");
-	if (!ofp) fatal_error("%s: %s", clp->arg, strerror(errno));
+	ofp = fopen(clp->vstr, "wb");
+	if (!ofp) fatal_error("%s: %s", clp->vstr, strerror(errno));
       }
       break;
-      
+
      case HELP_OPT:
       usage();
       exit(0);
       break;
-      
+
      case VERSION_OPT:
       printf("t1binary (LCDF t1utils) %s\n", VERSION);
       printf("Copyright (C) 1992-2003 I. Lee Hetherington, Eddie Kohler et al.\n\
@@ -216,52 +216,52 @@ There is NO warranty, not even for merchantability or fitness for a\n\
 particular purpose.\n");
       exit(0);
       break;
-      
+
      case Clp_NotOption:
       if (ifp && ofp)
 	fatal_error("too many arguments");
       else if (ifp)
 	goto output_file;
-      if (strcmp(clp->arg, "-") == 0)
+      if (strcmp(clp->vstr, "-") == 0)
 	ifp = stdin;
       else {
-	ifp_filename = clp->arg;
-	ifp = fopen(clp->arg, "r");
-	if (!ifp) fatal_error("%s: %s", clp->arg, strerror(errno));
+	ifp_filename = clp->vstr;
+	ifp = fopen(clp->vstr, "r");
+	if (!ifp) fatal_error("%s: %s", clp->vstr, strerror(errno));
       }
       break;
-      
+
      case Clp_Done:
       goto done;
-      
+
      case Clp_BadOption:
       short_usage();
       exit(1);
       break;
-      
+
     }
   }
-  
+
  done:
   if (!ifp) ifp = stdin;
   if (!ofp) ofp = stdout;
-  
+
 #if defined(_MSDOS) || defined(_WIN32)
   /* As we are processing a PFB (binary) output */
   /* file, we must set its file mode to binary. */
   _setmode(_fileno(ofp), _O_BINARY);
 #endif
-  
+
   /* prepare font reader and pfb writer */
   fr.output_ascii = pfb_output_ascii;
   fr.output_binary = pfb_output_binary;
   fr.output_end = pfb_output_end;
   init_pfb_writer(&w, max_blocklen, ofp);
-  
+
   /* peek at first byte to see if it is the PFB marker 0x80 */
   c = getc(ifp);
   ungetc(c, ifp);
-  
+
   /* do the file */
   if (c == PFB_MARKER)
     process_pfb(ifp, ifp_filename, &fr);
@@ -269,12 +269,12 @@ particular purpose.\n");
     process_pfa(ifp, ifp_filename, &fr);
   else
     fatal_error("%s does not start with font marker (`%%' or 0x80)", ifp_filename);
-  
+
   fclose(ifp);
   fclose(ofp);
-  
+
   if (!w.binary_blocks_written)
     fatal_error("no binary blocks written! Are you sure this was a font?");
-  
+
   return 0;
 }
